This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch master updated. glibc-2.28.9000-231-gb6e7c44


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  b6e7c449f9bb33943f10fdd8f3e539dceb136177 (commit)
      from  954cf3c29bd0b32bd11d5235b7e36148b187e77d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sourceware.org/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=b6e7c449f9bb33943f10fdd8f3e539dceb136177

commit b6e7c449f9bb33943f10fdd8f3e539dceb136177
Author: Samuel Thibault <samuel.thibault@ens-lyon.org>
Date:   Mon Oct 29 18:57:13 2018 +0100

    hurd: return EIEIO instead of EIO
    
    EIO would be understood as hardware failure, while this is software
    failure.
    
    	* hurd/intr-msg.c (_hurd_intr_rpc_mach_msg): Return EIEIO instead of EIO

diff --git a/ChangeLog b/ChangeLog
index 944d8fa..53fedc2 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -20,7 +20,7 @@
 
 	* hurd/hurdsig.c (_hurd_interrupted_rpc_timeout): Set to 60000.
 	* hurd/intr-msg.c (_hurd_intr_rpc_mach_msg): When the server does not
-	answer to interrupt_operation, return EIO instead of EINTR.
+	answer to interrupt_operation, return EIEIO instead of EINTR.
 	* sysdeps/mach/hurd/i386/intr-msg.h (INTR_MSG_TRAP): Make
 	_hurd_intr_rpc_msg_about_to global point to start of controlled
 	assembly snippet. Make it check canceled flag.
diff --git a/hurd/intr-msg.c b/hurd/intr-msg.c
index 7ace0a1..9ddae62 100644
--- a/hurd/intr-msg.c
+++ b/hurd/intr-msg.c
@@ -323,9 +323,9 @@ _hurd_intr_rpc_mach_msg (mach_msg_header_t *msg,
       /* FALLTHROUGH */
 
     dead:
-      err = EIO;
+      err = EIEIO;
 
       /* The EIO return indicates cancellation, so clear the flag.  */
       ss->cancel = 0;
       break;
 

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog       |    2 +-
@@ -323,9 +323,9 @@ _hurd_intr_rpc_mach_msg (mach_msg_header_t *msg,
 
-      /* The EIO return indicates cancellation, so clear the flag.  */
+      /* The EIEIO return indicates cancellation, so clear the flag.  */
       ss->cancel = 0;
       break;
 hurd/intr-msg.c |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]